@@ -1,37 +1,7 @@
-///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2004, Industrial Light & Magic, a division of Lucas
-// Digital Ltd. LLC
-// 
-// All rights reserved.
-// 
-// Redistribution and use in source and binary forms, with or without
-// modification, are permitted provided that the following conditions are
-// met:
-// *       Redistributions of source code must retain the above copyright
-// notice, this list of conditions and the following disclaimer.
-// *       Redistributions in binary form must reproduce the above
-// copyright notice, this list of conditions and the following disclaimer
-// in the documentation and/or other materials provided with the
-// distribution.
-// *       Neither the name of Industrial Light & Magic nor the names of
-// its contributors may be used to endorse or promote products derived
-// from this software without specific prior written permission. 
-// 
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+// SPDX-License-Identifier: BSD-3-Clause
+// Copyright (c) Contributors to the OpenEXR Project.
 //
-///////////////////////////////////////////////////////////////////////////
-
 
 #ifndef INCLUDED_IMF_TILED_OUTPUT_FILE_H
 #define INCLUDED_IMF_TILED_OUTPUT_FILE_H
@@ -42,15 +12,13 @@
 //
 //-----------------------------------------------------------------------------
 
-#include "ImfHeader.h"
-#include "ImfFrameBuffer.h"
-#include "ImathBox.h"
-#include "ImfTileDescription.h"
+#include "ImfForward.h"
+
 #include "ImfThreading.h"
 #include "ImfGenericOutputFile.h"
-#include "ImfForward.h"
-#include "ImfNamespace.h"
-#include "ImfExport.h"
+#include "ImfTileDescription.h"
+
+#include <ImathBox.h>
 
 
 OPENEXR_IMF_INTERNAL_NAMESPACE_HEADER_ENTER
@@ -59,7 +27,7 @@ OPENEXR_IMF_INTERNAL_NAMESPACE_HEADER_ENTER
 struct PreviewRgba;
 
 
-class IMF_EXPORT TiledOutputFile : public GenericOutputFile
+class IMF_EXPORT_TYPE TiledOutputFile : public GenericOutputFile
 {
   public:
 
@@ -85,6 +53,7 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // below).
     //-------------------------------------------------------------------
     
+    IMF_EXPORT
     TiledOutputFile (const char fileName[],
 		     const Header &header,
                      int numThreads = globalThreadCount ());
@@ -97,6 +66,7 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // close the corresponding files.
     // ----------------------------------------------------------------
 
+    IMF_EXPORT
     TiledOutputFile (OPENEXR_IMF_INTERNAL_NAMESPACE::OStream &os,
 		     const Header &header,
                      int numThreads = globalThreadCount ());
@@ -109,6 +79,7 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // have been written results in an incomplete file.
     //-----------------------------------------------------
     
+    IMF_EXPORT
     virtual ~TiledOutputFile ();
 
 
@@ -116,6 +87,7 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // Access to the file name
     //------------------------
     
+    IMF_EXPORT
     const char *	fileName () const;
 
 
@@ -123,6 +95,7 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // Access to the file header
     //--------------------------
     
+    IMF_EXPORT
     const Header &	header () const;
 
 
@@ -137,6 +110,7 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // after each call to writeTile().
     //-------------------------------------------------------
     
+    IMF_EXPORT
     void		setFrameBuffer (const FrameBuffer &frameBuffer);
 
 
@@ -144,6 +118,7 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // Access to the current frame buffer
     //-----------------------------------
     
+    IMF_EXPORT
     const FrameBuffer &	frameBuffer () const;
 
 
@@ -157,9 +132,13 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // fields of the file header's TileDescriptionAttribute.
     //---------------------------------------------------------
 
+    IMF_EXPORT
     unsigned int	tileXSize () const;
+    IMF_EXPORT
     unsigned int	tileYSize () const;
+    IMF_EXPORT
     LevelMode		levelMode () const;
+    IMF_EXPORT
     LevelRoundingMode	levelRoundingMode () const;
 
 
@@ -206,9 +185,13 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     //
     //--------------------------------------------------------------------
 
+    IMF_EXPORT
     int			numLevels () const;
+    IMF_EXPORT
     int			numXLevels () const;
+    IMF_EXPORT
     int			numYLevels () const;
+    IMF_EXPORT
     bool		isValidLevel (int lx, int ly) const;
 
 
@@ -230,7 +213,9 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     //
     //---------------------------------------------------------
 
+    IMF_EXPORT
     int			levelWidth  (int lx) const;
+    IMF_EXPORT
     int			levelHeight (int ly) const;
 
 
@@ -254,7 +239,9 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     //
     //----------------------------------------------------------
 
+    IMF_EXPORT
     int			numXTiles (int lx = 0) const;
+    IMF_EXPORT
     int			numYTiles (int ly = 0) const;
 
 
@@ -278,7 +265,9 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     //
     //---------------------------------------------------------
 
+    IMF_EXPORT
     IMATH_NAMESPACE::Box2i	dataWindowForLevel (int l = 0) const;
+    IMF_EXPORT
     IMATH_NAMESPACE::Box2i	dataWindowForLevel (int lx, int ly) const;
 
 
@@ -303,9 +292,11 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     //
     //-------------------------------------------------------------------
 
+    IMF_EXPORT
     IMATH_NAMESPACE::Box2i	dataWindowForTile (int dx, int dy,
 					   int l = 0) const;
 
+    IMF_EXPORT
     IMATH_NAMESPACE::Box2i	dataWindowForTile (int dx, int dy,
 					   int lx, int ly) const;
 
@@ -381,12 +372,16 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     //
     //------------------------------------------------------------------
 
+    IMF_EXPORT
     void		writeTile  (int dx, int dy, int l = 0);
+    IMF_EXPORT
     void		writeTile  (int dx, int dy, int lx, int ly);
 
+    IMF_EXPORT
     void		writeTiles (int dx1, int dx2, int dy1, int dy2,
                                     int lx, int ly);
 
+    IMF_EXPORT
     void		writeTiles (int dx1, int dx2, int dy1, int dy2,
                                     int l = 0);
 
@@ -399,8 +394,10 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // "lineOrder", "channels", and "tiles" attributes must be the same.
     //------------------------------------------------------------------
     
+    IMF_EXPORT
     void		copyPixels (TiledInputFile &in);
-    void                copyPixels (TiledInputPart &in);
+    IMF_EXPORT
+    void        copyPixels (TiledInputPart &in);
     
     
     //------------------------------------------------------------------
@@ -413,8 +410,10 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // To use this function, the InputFile must be tiled.
     //------------------------------------------------------------------
     
+    IMF_EXPORT
     void		copyPixels (InputFile &in);
-    void                copyPixels (InputPart &in);
+    IMF_EXPORT
+    void        copyPixels (InputPart &in);
 
     
 
@@ -436,6 +435,7 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     //
     //--------------------------------------------------------------
 
+    IMF_EXPORT
     void		updatePreviewImage (const PreviewRgba newPixels[]);
 
 
@@ -453,12 +453,13 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     //
     //-------------------------------------------------------------
 
+    IMF_EXPORT
     void		breakTile  (int dx, int dy,
 				    int lx, int ly,
 				    int offset,
 				    int length,
 				    char c);
-    struct Data;
+    struct IMF_HIDDEN Data;
 
   private:
 
@@ -468,16 +469,22 @@ class IMF_EXPORT TiledOutputFile : public GenericOutputFile
     // and lineOffsetsPosition which have been acquired from
     // the constructor of MultiPartOutputFile as well.
     // ----------------------------------------------------------------
+    IMF_HIDDEN
     TiledOutputFile (const OutputPartData* part);
 
-    TiledOutputFile (const TiledOutputFile &);		    // not implemented
-    TiledOutputFile & operator = (const TiledOutputFile &); // not implemented
+    TiledOutputFile (const TiledOutputFile &) = delete;
+    TiledOutputFile & operator = (const TiledOutputFile &) = delete;
+    TiledOutputFile (TiledOutputFile &&) = delete;
+    TiledOutputFile & operator = (TiledOutputFile &&) = delete;
 
+    IMF_HIDDEN
     void		initialize (const Header &header);
 
+    IMF_HIDDEN
     bool		isValidTile (int dx, int dy,
 				     int lx, int ly) const;
 
+    IMF_HIDDEN
     size_t		bytesPerLineForTile (int dx, int dy,
 					     int lx, int ly) const;
 
